==> open-xchange-calendar-printing_7.8.1.orig.tar.bz2: open-xchange-calendar-printing-7.8.1/com.openexchange.calendar.printing/src/com/openexchange/calendar/printing/blocks/CPPartition.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.calendar.printing.blocks;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import com.openexchange.calendar.printing.CPAppointment;

/**
 * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a>
 */
public class CPPartition {

    private List<CPAppointment> appointments = new LinkedList<CPAppointment>();

    private Map<String, String> metaData = new HashMap<String, String>();

    private List<CPFormattingInformation> formattingInformation = new LinkedList<CPFormattingInformation>();

    public void addAppointment(CPAppointment appointment) {
        appointments.add(appointment);
    }

    public void setAppointment(List<CPAppointment> appointments) {
        this.appointments = appointments;
    }

    public List<CPAppointment> getAppointments() {
        return appointments;
    }

    public boolean isEmpty() {
        return appointments.size() == 0;
    }

    public void setMetaData(Map<String, String> metaData) {
        this.metaData = metaData;
    }

    public Map<String, String> getMetaData() {
        return metaData;
    }

    public void setFormattingInformation(List<CPFormattingInformation> info) {
        this.formattingInformation = info;
    }

    public void addFormattingInformation(CPFormattingInformation info) {
        formattingInformation.add(info);
    }

    public List<CPFormattingInformation> getFormattingInformation() {
        return this.formattingInformation;
    }

}

==> open-xchange-calendar-printing_7.10.0.orig.tar.bz2: open-xchange-calendar-printing-7.10.0/com.openexchange.calendar.printing/src/com/openexchange/calendar/printing/blocks/CPPartition.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.calendar.printing.blocks;

import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import com.openexchange.calendar.printing.CPEvent;

/**
 * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a>
 */
public class CPPartition {

    private List<CPEvent> appointments = new LinkedList<CPEvent>();

    private Map<String, String> metaData = new HashMap<String, String>();

    private List<CPFormattingInformation> formattingInformation = new LinkedList<CPFormattingInformation>();

    public void addAppointment(CPEvent appointment) {
        appointments.add(appointment);
    }

    public void setAppointment(List<CPEvent> appointments) {
        this.appointments = appointments;
    }

    public List<CPEvent> getAppointments() {
        return appointments;
    }

    public boolean isEmpty() {
        return appointments.size() == 0;
    }

    public void setMetaData(Map<String, String> metaData) {
        this.metaData = metaData;
    }

    public Map<String, String> getMetaData() {
        return metaData;
    }

    public void setFormattingInformation(List<CPFormattingInformation> info) {
        this.formattingInformation = info;
    }

    public void addFormattingInformation(CPFormattingInformation info) {
        formattingInformation.add(info);
    }

    public List<CPFormattingInformation> getFormattingInformation() {
        return this.formattingInformation;
    }

}
